@@ -27,7 +27,9 @@ def activate_venv(path):
     # set current directory
     os.chdir(path)
     print("🔨 setting up your virutal environment")
-    os.system("python -m venv venv")
+    env = os.system("python -m venv env")
+    parent = os.getcwd()
+    project_path = path
 
     env_activate_script = ""
     if OS == "Windows":
@@ -40,9 +42,10 @@ def activate_venv(path):
 
 @app.command("")
 def main(template_name):
-    print("🔨 setting up your project")
     template_path = get_template_path(template_name)
     path = cookiecutter(template_path)
+    print("🔨 setting up your project")
+
     activate_venv(path)
     print("💥 your DRF project is ready!")
     folder_name = pathlib.PurePath(path)
